# `recon.dataset.Dataset`

`recon.dataset.Dataset` is a container to run other `recon` operations across your train/dev/test split
The `recon.dataset.Dataset.apply` function takes any of the other recon functions and runs them
on all the datasets in sequence.

---
## API

::: recon.Dataset
    :docstring:
    :members:
